@@ -1,5 +1,5 @@
 plot.PVE <- function(x,xlab="Number of Features",ylab="PVE",...) {
 
-  plot(x=x$J,y=x$PVE,xlab=xlab,ylab=ylab,...)
+  plot(x=x$J,y=x$PVEs,xlab=xlab,ylab=ylab,...)
 
 }
